@@ -55,11 +55,7 @@ package_installer_terminated (InstallerData *idata,
 			      FrErrorType    error_type,
 			      const char    *error_message)
 {
-	GdkWindow *window;
-
-	window = gtk_widget_get_window (GTK_WIDGET (idata->window));
-	if (window != NULL)
-		gdk_window_set_cursor (window, NULL);
+	gtk_widget_set_cursor (GTK_WIDGET (idata->window), NULL);
 
 	if (error_type != FR_ERROR_NONE) {
 		fr_window_batch_stop_with_error (idata->window,
@@ -68,7 +64,7 @@ package_installer_terminated (InstallerData *idata,
 						 error_message);
 	}
 	else {
-		update_registered_archives_capabilities ();
+		fr_update_registered_archives_capabilities ();
 		if (fr_window_is_batch_mode (idata->window))
 			fr_window_batch_resume (idata->window);
 		else
@@ -165,18 +161,9 @@ install_packages (InstallerData *idata)
 
 	connection = g_bus_get_sync (G_BUS_TYPE_SESSION, idata->cancellable, &error);
 	if (connection != NULL) {
-		GdkWindow  *window;
 		GDBusProxy *proxy;
 
-		window = gtk_widget_get_window (GTK_WIDGET (idata->window));
-		if (window != NULL) {
-			GdkCursor *cursor;
-
-			cursor = gdk_cursor_new_for_display (gdk_display_get_default(), GDK_WATCH);
-			gdk_window_set_cursor (window, cursor);
-
-			g_object_unref (cursor);
-		}
+		gtk_widget_set_cursor_from_name (GTK_WIDGET (idata->window), "wait");
 
 		proxy = g_dbus_proxy_new_sync (connection,
 					       G_DBUS_PROXY_FLAGS_NONE,
@@ -195,7 +182,7 @@ install_packages (InstallerData *idata)
 
 			names = g_strsplit (idata->packages, ",", -1);
 			real_names = get_packages_real_names (names);
-			desktop_startup_id = g_strdup_printf ("_TIME%i", gtk_get_current_event_time ());
+			desktop_startup_id = g_strdup_printf ("_TIME%i", 0 /* FIXME: delete if not needed */);
 			platform_data = g_variant_new_parsed ("{'desktop-startup-id': %v}", g_variant_new_take_string (desktop_startup_id));
 
 			g_dbus_proxy_call (proxy,
@@ -236,7 +223,7 @@ confirm_search_dialog_response_cb (GtkDialog *dialog,
 {
 	InstallerData *idata = user_data;
 
-	gtk_widget_destroy (GTK_WIDGET (dialog));
+	gtk_window_destroy (GTK_WINDOW (dialog));
 
 	if (response_id == GTK_RESPONSE_YES) {
 		install_packages (idata);
@@ -285,9 +272,9 @@ file_buffer_ready_cb (GObject      *source_object,
 	g_free (uri);
 	g_free (buffer);
 
-	archive_type = get_preferred_archive_for_mime_type (mime_type, FR_ARCHIVE_CAN_READ_WRITE);
+	archive_type = fr_get_preferred_archive_for_mime_type (mime_type, FR_ARCHIVE_CAN_READ_WRITE);
 	if (archive_type == 0)
-		archive_type = get_preferred_archive_for_mime_type (mime_type, FR_ARCHIVE_CAN_READ);
+		archive_type = fr_get_preferred_archive_for_mime_type (mime_type, FR_ARCHIVE_CAN_READ);
 	if (archive_type == 0) {
 		package_installer_terminated (idata, FR_ERROR_GENERIC, _("Archive type not supported."));
 		return;
@@ -307,9 +294,11 @@ file_buffer_ready_cb (GObject      *source_object,
 	{
 		char      *secondary_text;
 		GtkWidget *dialog;
+		g_autofree char *description;
 
+		description = g_content_type_get_description (mime_type);
 		secondary_text = g_strdup_printf (_("There is no command installed for %s files.\nDo you want to search for a command to open this file?"),
-						  g_content_type_get_description (mime_type));
+		                                  description);
 		dialog = _gtk_message_dialog_new (GTK_WINDOW (idata->window),
 						  GTK_DIALOG_MODAL,
 						  _("Could not open this file type"),
@@ -317,8 +306,8 @@ file_buffer_ready_cb (GObject      *source_object,
 						  _GTK_LABEL_CANCEL, GTK_RESPONSE_NO,
 						  _("_Search Command"), GTK_RESPONSE_YES,
 						  NULL);
-		g_signal_connect (dialog, "response", G_CALLBACK (confirm_search_dialog_response_cb), idata);
-		gtk_widget_show (dialog);
+		g_signal_connect (GTK_MESSAGE_DIALOG (dialog), "response", G_CALLBACK (confirm_search_dialog_response_cb), idata);
+		gtk_window_present (GTK_WINDOW (dialog));
 
 		g_free (secondary_text);
 	}
