@@ -21,6 +21,7 @@
 
 
 #include <config.h>
+#include <adwaita.h>
 #include "fr-application.h"
 #include "fr-application-menu.h"
 #include "fr-enum-types.h"
@@ -122,21 +123,23 @@ fr_application_activate_about (GSimpleAction *action,
 			       GVariant      *parameter,
 			       gpointer       user_data)
 {
-	const char *authors[] = { "Paolo Bacchilega <paolo.bacchilega@libero.it>", NULL	};
+	const char *developers[] = { "Paolo Bacchilega <paolo.bacchilega@libero.it>", NULL };
 	const char *documenters [] = { "Alexander Kirillov", "Breda McColgan", NULL };
 
-	gtk_show_about_dialog (GTK_WINDOW (_gtk_application_get_current_window (G_APPLICATION (user_data))),
-			       "version", PACKAGE_VERSION,
-			       "copyright", _("Copyright \xc2\xa9 2001–2014 Free Software Foundation, Inc."),
-			       "comments", _("An archive manager for GNOME."),
-			       "authors", authors,
-			       "documenters", documenters,
-			       "translator-credits", _("translator-credits"),
-			       "logo-icon-name", "org.gnome.FileRoller",
-			       "license-type", GTK_LICENSE_GPL_2_0,
-			       "website", "https://wiki.gnome.org/Apps/FileRoller",
-			       "wrap-license", TRUE,
-			       NULL);
+	adw_show_about_window (
+		gtk_application_get_active_window (GTK_APPLICATION (user_data)),
+		"application-name", _("File Roller"),
+		"application-icon", "org.gnome.FileRoller",
+		"version", PACKAGE_VERSION,
+		"copyright", _("Copyright \xc2\xa9 2001–2023 Free Software Foundation, Inc."),
+		"comments", _("An archive manager for GNOME."),
+		"website", "https://wiki.gnome.org/Apps/FileRoller",
+		"issue-url", "https://gitlab.gnome.org/GNOME/file-roller/-/issues/new",
+		"license-type", GTK_LICENSE_GPL_2_0,
+		"developers", developers,
+		"documenters", documenters,
+		"translator-credits", _("translator-credits"),
+		NULL);
 }
 
 
@@ -145,7 +148,13 @@ fr_application_activate_quit (GSimpleAction *action,
 			      GVariant      *parameter,
 			      gpointer       user_data)
 {
-	g_application_quit (G_APPLICATION (user_data));
+	GList *windows;
+	GList *scan;
+
+	windows = g_list_copy (gtk_application_get_windows (GTK_APPLICATION (user_data)));
+	for (scan = windows; scan; scan = scan->next)
+		fr_window_close (FR_WINDOW (scan->data));
+	g_list_free (windows);
 }
 
 
@@ -250,39 +259,3 @@ fr_initialize_app_menu (GApplication *application)
 			  G_CALLBACK (pref_list_mode_changed),
 			  application);
 }
-
-
-void
-fr_initialize_app_menubar (GApplication *application)
-{
-	GtkBuilder *builder;
-	GSettings  *settings;
-
-	g_action_map_add_action_entries (G_ACTION_MAP (application),
-					 app_menu_entries,
-					 G_N_ELEMENTS (app_menu_entries),
-					 application);
-
-	builder = gtk_builder_new_from_resource (FILE_ROLLER_RESOURCE_UI_PATH "app-menubar.ui");
-	gtk_application_set_menubar (GTK_APPLICATION (application),
-				     G_MENU_MODEL (gtk_builder_get_object (builder, "app-menubar")));
-	g_object_unref (builder);
-
-	settings = fr_application_get_settings (FR_APPLICATION (application), FILE_ROLLER_SCHEMA_UI);
-	g_simple_action_set_state (GET_ACTION (PREF_UI_VIEW_SIDEBAR),
-				   g_variant_new_boolean (g_settings_get_boolean (settings, PREF_UI_VIEW_SIDEBAR)));
-
-	settings = fr_application_get_settings (FR_APPLICATION (application), FILE_ROLLER_SCHEMA_LISTING);
-	g_simple_action_set_state (GET_ACTION (PREF_LISTING_LIST_MODE),
-				   g_variant_new_string (_g_enum_type_get_value (FR_TYPE_WINDOW_LIST_MODE,
-						   	 g_settings_get_enum (settings, PREF_LISTING_LIST_MODE))->value_nick));
-
-	g_signal_connect (fr_application_get_settings (FR_APPLICATION (application), FILE_ROLLER_SCHEMA_UI),
-			  "changed::" PREF_UI_VIEW_SIDEBAR,
-			  G_CALLBACK (pref_view_sidebar_changed),
-			  application);
-	g_signal_connect (fr_application_get_settings (FR_APPLICATION (application), FILE_ROLLER_SCHEMA_LISTING),
-			  "changed::" PREF_LISTING_LIST_MODE,
-			  G_CALLBACK (pref_list_mode_changed),
-			  application);
-}
