@@ -26,7 +26,6 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-void initialize_app_menu (GApplication *application);
-void initialize_app_menubar (GApplication *application);
+void fr_initialize_app_menu (GApplication *application);
 
 #endif /* APP_MENU_H */
