@@ -28,7 +28,6 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <glib/gprintf.h>
-#include <handy.h>
 #include "file-utils.h"
 #include "fr-application.h"
 #include "fr-application-menu.h"
@@ -110,7 +109,7 @@ action_open_archive (GSimpleAction      *action,
 
 	saved_file = g_file_new_for_path (g_variant_get_string (value, NULL));
 	new_window = fr_window_new ();
-	gtk_widget_show (new_window);
+	gtk_window_present (GTK_WINDOW (new_window));
 	fr_window_archive_open (FR_WINDOW (new_window),
 				saved_file,
 				GTK_WINDOW (new_window));
@@ -184,7 +183,6 @@ handle_method_call (GDBusConnection       *connection,
 		int  *supported_types = NULL;
 
 		g_variant_get (parameters, "(s)", &action);
-
 		if (g_strcmp0 (action, "create") == 0) {
 			supported_types = save_type;
 		}
@@ -321,7 +319,7 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (FR_WINDOW (window), "progress", G_CALLBACK (window_progress_cb), connection);
 		g_signal_connect (FR_WINDOW (window), "ready", G_CALLBACK (window_ready_cb), invocation);
 
-		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
+		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract"));
 		fr_window_batch__extract (FR_WINDOW (window), archive, destination, use_progress_dialog);
 		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
 		fr_window_batch_start (FR_WINDOW (window));
@@ -347,7 +345,7 @@ handle_method_call (GDBusConnection       *connection,
 		g_signal_connect (FR_WINDOW (window), "progress", G_CALLBACK (window_progress_cb), connection);
 		g_signal_connect (FR_WINDOW (window), "ready", G_CALLBACK (window_ready_cb), invocation);
 
-		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
+		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract"));
 		fr_window_batch__extract_here (FR_WINDOW (window), archive, use_progress_dialog);
 		fr_window_batch_append_action (FR_WINDOW (window), FR_BATCH_ACTION_QUIT, NULL, NULL);
 		fr_window_batch_start (FR_WINDOW (window));
@@ -367,7 +365,7 @@ static const GDBusInterfaceVTable interface_vtable = {
 
 
 struct _FrApplication {
-	GtkApplication  parent_instance;
+	AdwApplication  parent_instance;
 	GDBusNodeInfo  *introspection_data;
 	guint           owner_id;
 	GSettings      *listing_settings;
@@ -375,7 +373,7 @@ struct _FrApplication {
 };
 
 
-G_DEFINE_TYPE (FrApplication, fr_application, GTK_TYPE_APPLICATION)
+G_DEFINE_TYPE (FrApplication, fr_application, ADW_TYPE_APPLICATION)
 
 
 static void
@@ -470,35 +468,18 @@ fr_application_register_archive_manager_service (FrApplication *self)
 static void
 fr_application_startup (GApplication *application)
 {
-	GtkSettings	*gtk_settings;
-	gboolean	 shell_shows_menubar;
-
-    g_application_set_resource_base_path (application, "/org/gnome/FileRoller");
 	G_APPLICATION_CLASS (fr_application_parent_class)->startup (application);
 
-	g_set_application_name (_("Archive Manager"));
-	gtk_window_set_default_icon_name ("org.gnome.ArchiveManager");
-
+	g_set_application_name (_("File Roller"));
+	gtk_window_set_default_icon_name ("org.gnome.FileRoller");
+	g_application_set_resource_base_path (application, "/org/gnome/FileRoller");
 	fr_application_register_archive_manager_service (FR_APPLICATION (application));
 	fr_initialize_data ();
 
-	/* use the menubar only when the shell shows the menu bar */
+	fr_initialize_app_menu (application);
 
-	gtk_settings = gtk_settings_get_default ();
-	g_object_get (G_OBJECT (gtk_settings),
-		      "gtk-shell-shows-menubar", &shell_shows_menubar,
-		      NULL);
+	/* Setup actions. */
 
-	hdy_init ();
-	hdy_style_manager_set_color_scheme (hdy_style_manager_get_default (),
-					    HDY_COLOR_SCHEME_PREFER_LIGHT);
-
-	if (shell_shows_menubar)
-		fr_initialize_app_menubar (application);
-	else
-		fr_initialize_app_menu (application);
-
-	/* Setup actions */
 	g_action_map_add_action_entries (G_ACTION_MAP (application), entries,
 					 G_N_ELEMENTS (entries), NULL);
 }
@@ -508,18 +489,12 @@ static GOptionContext *
 fr_application_create_option_context (void)
 {
 	GOptionContext *context;
-	static gsize    initialized = FALSE;
 
 	context = g_option_context_new (N_("— Create and modify an archive"));
 	g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
 	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 	g_option_context_set_ignore_unknown_options (context, TRUE);
 
-	if (g_once_init_enter (&initialized)) {
-		g_option_context_add_group (context, gtk_get_option_group (TRUE));
-		g_once_init_leave (&initialized, TRUE);
-	}
-
 	return context;
 }
 
@@ -528,9 +503,6 @@ static int
 fr_application_command_line_finished (GApplication *application,
 				      int           status)
 {
-	if (status == EXIT_SUCCESS)
-		gdk_notify_startup_complete ();
-
 	/* reset arguments */
 
 	remaining_args = NULL;
@@ -576,7 +548,7 @@ fr_application_command_line (GApplication            *application,
 
 	if (remaining_args == NULL) { /* No archive specified. */
 		if (! arg_service)
-			gtk_widget_show (fr_window_new ());
+			gtk_window_present (GTK_WINDOW (fr_window_new ()));
 		return fr_application_command_line_finished (application, EXIT_SUCCESS);
 	}
 
@@ -630,7 +602,7 @@ fr_application_command_line (GApplication            *application,
 
 		fr_window_set_notify (FR_WINDOW (window), arg_notify);
 
-		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract archive"));
+		fr_window_batch_new (FR_WINDOW (window), C_("Window title", "Extract"));
 		while ((archive = remaining_args[i++]) != NULL) {
 			GFile    *file;
 			gboolean  last_archive;
@@ -658,7 +630,7 @@ fr_application_command_line (GApplication            *application,
 			GFile     *file;
 
 			window = fr_window_new ();
-			gtk_widget_show (window);
+			gtk_window_present (GTK_WINDOW (window));
 
 			file = g_application_command_line_create_file_for_arg (command_line, filename);
 			fr_window_archive_open (FR_WINDOW (window), file, GTK_WINDOW (window));
@@ -702,7 +674,7 @@ fr_application_local_command_line (GApplication   *application,
 	}
 
 	if (arg_version) {
-		g_printf ("%s %s, Copyright © 2001-2012 Free Software Foundation, Inc.\n", PACKAGE_NAME, PACKAGE_VERSION);
+		g_printf ("%s %s, Copyright © 2001-2022 Free Software Foundation, Inc.\n", PACKAGE_NAME, PACKAGE_VERSION);
 		handled_locally = TRUE;
 	}
 
@@ -725,8 +697,6 @@ fr_application_activate (GApplication *application)
 		if (! fr_window_is_batch_mode (FR_WINDOW (link->data)))
 			gtk_widget_show (GTK_WIDGET (link->data));
 	}
-
-	gdk_notify_startup_complete ();
 }
 
 
@@ -760,10 +730,11 @@ fr_application_init (FrApplication *self)
 GtkApplication *
 fr_application_new (void)
 {
-        return g_object_new (fr_application_get_type (),
-                             "application-id", "org.gnome.FileRoller",
-                             "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
-                             NULL);
+	return g_object_new (fr_application_get_type (),
+			     "application-id", "org.gnome.FileRoller",
+			     "flags", G_APPLICATION_HANDLES_COMMAND_LINE,
+			     "resource-base-path", "/org/gnome/FileRoller/",
+			     NULL);
 }
 
 
