@@ -27,7 +27,7 @@
 #include <time.h>
 #include <fcntl.h>
 #include <glib.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "glib-utils.h"
 #include "fr-command.h"
@@ -102,12 +102,12 @@ list__process_line (char     *line,
 		    gpointer  data)
 {
 	FrCommand  *comm = FR_COMMAND (data);
-	FileData   *fdata;
+	FrFileData *fdata;
 	char      **fields;
 	GFile      *file;
 	char       *filename;
 
-	fdata = file_data_new ();
+	fdata = fr_file_data_new ();
 
 	fields = _g_str_split_line (line, 2);
 	if (strcmp (fields[1], "-1") != 0)
@@ -134,7 +134,7 @@ list__process_line (char     *line,
 	fdata->path = _g_path_remove_level (fdata->full_path);
 
 	if (*fdata->name == 0)
-		file_data_free (fdata);
+		fr_file_data_free (fdata);
 	else
 		fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 
@@ -163,11 +163,11 @@ fr_command_cfile_list (FrCommand *comm)
 		 * simply use the archive size, suboptimal but there is no
 		 * alternative. */
 
-		FileData *fdata;
+		FrFileData *fdata;
 		char     *filename;
 		GFile    *file;
 
-		fdata = file_data_new ();
+		fdata = fr_file_data_new ();
 
 		filename = _g_path_remove_first_extension (comm->filename);
 		fdata->full_path = g_strconcat ("/",
@@ -185,7 +185,7 @@ fr_command_cfile_list (FrCommand *comm)
 		fdata->path = _g_path_remove_level (fdata->full_path);
 
 		if (*fdata->name == 0)
-			file_data_free (fdata);
+			fr_file_data_free (fdata);
 		else
 			fr_archive_add_file (FR_ARCHIVE (comm), fdata);
 
@@ -548,12 +548,12 @@ fr_command_cfile_get_mime_types (FrArchive *archive)
 }
 
 
-static FrArchiveCap
+static FrArchiveCaps
 fr_command_cfile_get_capabilities (FrArchive  *archive,
 			           const char *mime_type,
 				   gboolean    check_command)
 {
-	FrArchiveCap capabilities;
+	FrArchiveCaps capabilities;
 
 	capabilities = FR_ARCHIVE_CAN_DO_NOTHING;
 	if (_g_mime_type_matches (mime_type, "application/x-gzip")) {
@@ -612,27 +612,27 @@ fr_command_cfile_get_packages (FrArchive  *archive,
 			       const char *mime_type)
 {
 	if (_g_mime_type_matches (mime_type, "application/x-gzip"))
-		return PACKAGES ("gzip");
+		return FR_PACKAGES ("gzip");
 	else if (_g_mime_type_matches (mime_type, "application/x-brotli"))
-		return PACKAGES ("brotli");
+		return FR_PACKAGES ("brotli");
 	else if (_g_mime_type_matches (mime_type, "application/x-bzip"))
-		return PACKAGES ("bzip2");
+		return FR_PACKAGES ("bzip2");
 	else if (_g_mime_type_matches (mime_type, "application/x-compress"))
-		return PACKAGES ("ncompress");
+		return FR_PACKAGES ("ncompress");
 	else if (_g_mime_type_matches (mime_type, "application/x-lzip"))
-		return PACKAGES ("lzip");
+		return FR_PACKAGES ("lzip");
 	else if (_g_mime_type_matches (mime_type, "application/x-lzma"))
-		return PACKAGES ("lzma");
+		return FR_PACKAGES ("lzma");
 	else if (_g_mime_type_matches (mime_type, "application/x-xz"))
-		return PACKAGES ("xz");
+		return FR_PACKAGES ("xz");
 	else if (_g_mime_type_matches (mime_type, "application/x-lzop"))
-		return PACKAGES ("lzop");
+		return FR_PACKAGES ("lzop");
 	else if (_g_mime_type_matches (mime_type, "application/x-rzip"))
-		return PACKAGES ("rzip");
+		return FR_PACKAGES ("rzip");
 	else if (_g_mime_type_matches (mime_type, "application/x-lz4"))
-		return PACKAGES ("lz4");
+		return FR_PACKAGES ("lz4");
 	else if (_g_mime_type_matches (mime_type, "application/zstd"))
-		return PACKAGES ("zstd");
+		return FR_PACKAGES ("zstd");
 
 	return NULL;
 }
