@@ -20,11 +20,13 @@
  */
 
 #include <config.h>
+#include "fr-enum-types.h"
 #include "fr-file-selector-dialog.h"
+#include "fr-location-bar.h"
+#include "fr-places-sidebar.h"
 #include "gio-utils.h"
 #include "glib-utils.h"
 #include "gtk-utils.h"
-#include "gth-icon-cache.h"
 
 
 #define GET_WIDGET(x) (_gtk_builder_get_widget (self->builder, (x)))
@@ -35,6 +37,10 @@
 #define FILE_LIST_CHARS 60
 #define SIDEBAR_CHARS   12
 
+enum {
+	PROP_0,
+	PROP_SELECTION_MODE,
+};
 
 enum {
 	FILE_LIST_COLUMN_ICON,
@@ -97,23 +103,77 @@ load_data_free (LoadData *load_data)
 
 
 struct _FrFileSelectorDialog {
-	GtkDialog      parent_instance;
-	GtkBuilder    *builder;
-	GtkWidget     *extra_widget;
-	GFile         *current_folder;
-	LoadData      *current_operation;
-	GthIconCache  *icon_cache;
-	GSettings     *settings;
-	gboolean       show_hidden;
+	GtkDialog           parent_instance;
+	GtkBuilder         *builder;
+	GtkWidget          *extra_widget;
+	GFile              *current_folder;
+	LoadData           *current_operation;
+	GSettings          *settings;
+	gboolean            show_hidden;
 	GSimpleActionGroup *action_map;
-	GtkPopover *file_context_menu;
-
+	GtkPopover         *file_context_menu;
+	GtkWidget          *location_bar;
+	FrFileSelectorMode  selection_mode;
+	GtkWidget          *places_sidebar;
 };
 
 
 G_DEFINE_TYPE (FrFileSelectorDialog, fr_file_selector_dialog, GTK_TYPE_DIALOG)
 
 
+static void
+set_selection_mode (FrFileSelectorDialog *self,
+		    FrFileSelectorMode    mode)
+{
+	self->selection_mode = mode;
+	gtk_cell_renderer_set_visible (GTK_CELL_RENDERER (GET_WIDGET ("is_selected_cellrenderertoggle")),
+				       (self->selection_mode == FR_FILE_SELECTOR_MODE_FILES));
+	gtk_tree_view_column_set_visible (GTK_TREE_VIEW_COLUMN (GET_WIDGET ("treeviewcolumn_size")),
+					  (self->selection_mode == FR_FILE_SELECTOR_MODE_FILES));
+	g_simple_action_set_enabled (G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (self->action_map), "select-all")), (self->selection_mode == FR_FILE_SELECTOR_MODE_FILES));
+	g_simple_action_set_enabled (G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (self->action_map), "deselect-all")), (self->selection_mode == FR_FILE_SELECTOR_MODE_FILES));
+}
+
+
+static void
+fr_file_selector_set_property (GObject      *object,
+			       guint         property_id,
+			       const GValue *value,
+			       GParamSpec   *pspec)
+{
+	FrFileSelectorDialog *self = FR_FILE_SELECTOR_DIALOG (object);
+
+	switch (property_id) {
+	case PROP_SELECTION_MODE:
+		set_selection_mode (self, g_value_get_enum (value));
+		break;
+
+	default:
+		break;
+	}
+}
+
+
+static void
+fr_file_selector_get_property (GObject    *object,
+			       guint       property_id,
+			       GValue     *value,
+			       GParamSpec *pspec)
+{
+	FrFileSelectorDialog *self = FR_FILE_SELECTOR_DIALOG (object);
+
+	switch (property_id) {
+	case PROP_SELECTION_MODE:
+		g_value_set_enum (value, self->selection_mode);
+		break;
+
+	default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
+	}
+}
+
+
 static void
 fr_file_selector_dialog_finalize (GObject *object)
 {
@@ -137,8 +197,6 @@ static void
 set_current_folder (FrFileSelectorDialog *self,
 		    GFile                *folder)
 {
-	char *folder_name;
-
 	if (folder != self->current_folder) {
 		_g_object_unref (self->current_folder);
 		self->current_folder = g_object_ref (folder);
@@ -147,60 +205,8 @@ set_current_folder (FrFileSelectorDialog *self,
 	if (self->current_folder == NULL)
 		return;
 
-	folder_name = g_file_get_parse_name (folder);
-	gtk_entry_set_text (GTK_ENTRY (GET_WIDGET ("location_entry")), folder_name);
-	g_free (folder_name);
-
-	gtk_places_sidebar_set_location (GTK_PLACES_SIDEBAR (GET_WIDGET ("places_sidebar")), folder);
-}
-
-
-/* Taken from the Gtk+ file gtkfilechooserdefault.c
- * Copyright (C) 2003, Red Hat, Inc.
- *
- * Changed by File-Roller authors
- *
- * Guesses a size based upon font sizes */
-static int
-get_font_size (GtkWidget *widget)
-{
-	GtkStyleContext      *context;
-	GtkStateFlags         state;
-	int                   font_size;
-	GdkScreen            *screen;
-	double                resolution;
-	PangoFontDescription *font;
-
-	context = gtk_widget_get_style_context (widget);
-	state = gtk_widget_get_state_flags (widget);
-
-	screen = gtk_widget_get_screen (widget);
-	if (screen) {
-		resolution = gdk_screen_get_resolution (screen);
-		if (resolution < 0.0) /* will be -1 if the resolution is not defined in the GdkScreen */
-			resolution = 96.0;
-	}
-	else
-		resolution = 96.0; /* wheeee */
-
-	gtk_style_context_get (context, state, "font", &font, NULL);
-	font_size = pango_font_description_get_size (font);
-	font_size = PANGO_PIXELS (font_size) * resolution / 72.0;
-
-	return font_size;
-}
-
-
-static void
-find_good_window_size_from_style (GtkWidget *widget,
-				  int       *width,
-				  int       *height)
-{
-	int font_size;
-
-	font_size = get_font_size (widget);
-	*width = font_size * FILE_LIST_CHARS;
-	*height = font_size * FILE_LIST_LINES;
+	fr_location_bar_set_location (FR_LOCATION_BAR (self->location_bar), folder);
+	fr_places_sidebar_set_location (FR_PLACES_SIDEBAR (self->places_sidebar), folder);
 }
 
 
@@ -218,7 +224,8 @@ fr_file_selector_dialog_get_default_size (FrFileSelectorDialog *self,
 		return;
 	}
 
-	find_good_window_size_from_style (GTK_WIDGET (self), default_width, default_height);
+	*default_width = 300;
+	*default_height = 300;
 
 	if ((self->extra_widget != NULL) && gtk_widget_get_visible (self->extra_widget)) {
 		GtkRequisition req;
@@ -244,41 +251,19 @@ static void
 fr_file_selector_dialog_realize (GtkWidget *widget)
 {
 	FrFileSelectorDialog *self;
-	GIcon                *icon;
 	int                   sidebar_size;
 
 	GTK_WIDGET_CLASS (fr_file_selector_dialog_parent_class)->realize (widget);
 
 	self = FR_FILE_SELECTOR_DIALOG (widget);
-
-	self->icon_cache = gth_icon_cache_new_for_widget (GTK_WIDGET (self), GTK_ICON_SIZE_MENU);
-	icon = g_content_type_get_icon ("text/plain");
-	gth_icon_cache_set_fallback (self->icon_cache, icon);
-	g_object_unref (icon);
-
 	_fr_file_selector_dialog_update_size (self);
-
 	sidebar_size = g_settings_get_int (self->settings, PREF_FILE_SELECTOR_SIDEBAR_SIZE);
 	if (sidebar_size <= 0)
-		sidebar_size = get_font_size (widget) * SIDEBAR_CHARS;
+		sidebar_size = 300;
 	gtk_paned_set_position (GTK_PANED (GET_WIDGET ("main_paned")), sidebar_size);
 }
 
 
-static void
-fr_file_selector_dialog_unrealize (GtkWidget *widget)
-{
-	FrFileSelectorDialog *self;
-
-	self = FR_FILE_SELECTOR_DIALOG (widget);
-
-	gth_icon_cache_free (self->icon_cache);
-	self->icon_cache = NULL;
-
-	GTK_WIDGET_CLASS (fr_file_selector_dialog_parent_class)->unrealize (widget);
-}
-
-
 static void
 fr_file_selector_dialog_unmap (GtkWidget *widget)
 {
@@ -288,7 +273,7 @@ fr_file_selector_dialog_unmap (GtkWidget *widget)
 
 	self = FR_FILE_SELECTOR_DIALOG (widget);
 
-	gtk_window_get_size (GTK_WINDOW (self), &width, &height);
+	gtk_widget_get_size_request (GTK_WIDGET (self), &width, &height);
 	g_settings_set (self->settings, PREF_FILE_SELECTOR_WINDOW_SIZE, "(ii)", width, height);
 	g_settings_set_boolean (self->settings, PREF_FILE_SELECTOR_SHOW_HIDDEN, self->show_hidden);
 	g_settings_set_int (self->settings,
@@ -310,12 +295,22 @@ fr_file_selector_dialog_class_init (FrFileSelectorDialogClass *klass)
 	GtkWidgetClass *widget_class;
 
 	object_class = (GObjectClass*) klass;
+	object_class->set_property = fr_file_selector_set_property;
+	object_class->get_property = fr_file_selector_get_property;
 	object_class->finalize = fr_file_selector_dialog_finalize;
 
 	widget_class = (GtkWidgetClass *) klass;
 	widget_class->realize = fr_file_selector_dialog_realize;
-	widget_class->unrealize = fr_file_selector_dialog_unrealize;
 	widget_class->unmap = fr_file_selector_dialog_unmap;
+
+	g_object_class_install_property (object_class,
+					 PROP_SELECTION_MODE,
+					 g_param_spec_enum ("selection-mode",
+							    "Selection mode",
+							    "The selection mode",
+							    FR_TYPE_FILE_SELECTOR_MODE,
+							    FR_FILE_SELECTOR_MODE_FILES,
+							    G_PARAM_CONSTRUCT | G_PARAM_READWRITE));
 }
 
 
@@ -326,36 +321,36 @@ files_name_column_sort_func (GtkTreeModel *model,
 			     gpointer      user_data)
 {
 	GtkSortType  sort_order;
-        char        *key_a;
-        char        *key_b;
-        gboolean     is_folder_a;
-        gboolean     is_folder_b;
-        gint         result;
+	char        *key_a;
+	char        *key_b;
+	gboolean     is_folder_a;
+	gboolean     is_folder_b;
+	gint         result;
 
 	gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE (model), NULL, &sort_order);
 
-        gtk_tree_model_get (model, a,
-        		    FILE_LIST_COLUMN_NAME_ORDER, &key_a,
-        		    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_a,
-                            -1);
-        gtk_tree_model_get (model, b,
-        		    FILE_LIST_COLUMN_NAME_ORDER, &key_b,
-        		    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_b,
-                            -1);
+	gtk_tree_model_get (model, a,
+			    FILE_LIST_COLUMN_NAME_ORDER, &key_a,
+			    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_a,
+			    -1);
+	gtk_tree_model_get (model, b,
+			    FILE_LIST_COLUMN_NAME_ORDER, &key_b,
+			    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_b,
+			    -1);
 
-        if (is_folder_a == is_folder_b) {
-        	result = strcmp (key_a, key_b);
-        }
-        else {
-        	result = is_folder_a ? -1 : 1;
-        	if (sort_order == GTK_SORT_DESCENDING)
-        		result = -1 * result;
-        }
+	if (is_folder_a == is_folder_b) {
+		result = strcmp (key_a, key_b);
+	}
+	else {
+		result = is_folder_a ? -1 : 1;
+		if (sort_order == GTK_SORT_DESCENDING)
+			result = -1 * result;
+	}
 
-        g_free (key_a);
-        g_free (key_b);
+	g_free (key_a);
+	g_free (key_b);
 
-        return result;
+	return result;
 }
 
 
@@ -366,46 +361,46 @@ files_size_column_sort_func (GtkTreeModel *model,
 			     gpointer      user_data)
 {
 	GtkSortType  sort_order;
-        char        *key_a;
-        char        *key_b;
-        gint64       size_a;
-        gint64       size_b;
-        gboolean     is_folder_a;
-        gboolean     is_folder_b;
-        int          result;
+	char        *key_a;
+	char        *key_b;
+	gint64       size_a;
+	gint64       size_b;
+	gboolean     is_folder_a;
+	gboolean     is_folder_b;
+	int          result;
 
-        gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE (model), NULL, &sort_order);
+	gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE (model), NULL, &sort_order);
 
-        gtk_tree_model_get (model, a,
-        		    FILE_LIST_COLUMN_NAME_ORDER, &key_a,
-        		    FILE_LIST_COLUMN_SIZE_ORDER, &size_a,
-        		    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_a,
-                            -1);
-        gtk_tree_model_get (model, b,
-        		    FILE_LIST_COLUMN_NAME_ORDER, &key_b,
-        		    FILE_LIST_COLUMN_SIZE_ORDER, &size_b,
-        		    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_b,
-                            -1);
+	gtk_tree_model_get (model, a,
+			    FILE_LIST_COLUMN_NAME_ORDER, &key_a,
+			    FILE_LIST_COLUMN_SIZE_ORDER, &size_a,
+			    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_a,
+			    -1);
+	gtk_tree_model_get (model, b,
+			    FILE_LIST_COLUMN_NAME_ORDER, &key_b,
+			    FILE_LIST_COLUMN_SIZE_ORDER, &size_b,
+			    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_b,
+			    -1);
 
-        if (is_folder_a == is_folder_b) {
-        	if (is_folder_a) {
-                	result = strcmp (key_a, key_b);
-                	if (sort_order == GTK_SORT_DESCENDING)
-                		result = -1 * result;
-        	}
-        	else
-        		result = size_a - size_b;
-        }
-        else {
-        	result = is_folder_a ? -1 : 1;
-        	if (sort_order == GTK_SORT_DESCENDING)
-        		result = -1 * result;
-        }
+	if (is_folder_a == is_folder_b) {
+		if (is_folder_a) {
+			result = strcmp (key_a, key_b);
+			if (sort_order == GTK_SORT_DESCENDING)
+				result = -1 * result;
+		}
+		else
+			result = size_a - size_b;
+	}
+	else {
+		result = is_folder_a ? -1 : 1;
+		if (sort_order == GTK_SORT_DESCENDING)
+			result = -1 * result;
+	}
 
-        g_free (key_a);
-        g_free (key_b);
+	g_free (key_a);
+	g_free (key_b);
 
-        return result;
+	return result;
 }
 
 
@@ -416,38 +411,38 @@ files_modified_column_sort_func (GtkTreeModel *model,
 				 gpointer      user_data)
 {
 	GtkSortType sort_order;
-        glong       modified_a;
-        glong       modified_b;
-        gboolean    is_folder_a;
-        gboolean    is_folder_b;
-        int         result;
+	glong       modified_a;
+	glong       modified_b;
+	gboolean    is_folder_a;
+	gboolean    is_folder_b;
+	int         result;
 
-        gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE (model), NULL, &sort_order);
+	gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE (model), NULL, &sort_order);
 
-        gtk_tree_model_get (model, a,
-        		    FILE_LIST_COLUMN_MODIFIED_ORDER, &modified_a,
-        		    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_a,
-                            -1);
-        gtk_tree_model_get (model, b,
-        		    FILE_LIST_COLUMN_MODIFIED_ORDER, &modified_b,
-        		    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_b,
-                            -1);
+	gtk_tree_model_get (model, a,
+			    FILE_LIST_COLUMN_MODIFIED_ORDER, &modified_a,
+			    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_a,
+			    -1);
+	gtk_tree_model_get (model, b,
+			    FILE_LIST_COLUMN_MODIFIED_ORDER, &modified_b,
+			    FILE_LIST_COLUMN_IS_FOLDER, &is_folder_b,
+			    -1);
 
-        if (is_folder_a == is_folder_b) {
-        	result = modified_a - modified_b;
-        }
-        else {
-        	result = is_folder_a ? -1 : 1;
-        	if (sort_order == GTK_SORT_DESCENDING)
-        		result = -1 * result;
-        }
+	if (is_folder_a == is_folder_b) {
+		result = modified_a - modified_b;
+	}
+	else {
+		result = is_folder_a ? -1 : 1;
+		if (sort_order == GTK_SORT_DESCENDING)
+			result = -1 * result;
+	}
 
-        return result;
+	return result;
 }
 
 
 static gboolean
-_fr_file_selector_dialog_is_file_selected (FrFileSelectorDialog *self)
+_fr_file_selector_dialog_is_file_checked (FrFileSelectorDialog *self)
 {
 	GtkListStore *list_store;
 	GtkTreeIter   iter;
@@ -471,6 +466,16 @@ _fr_file_selector_dialog_is_file_selected (FrFileSelectorDialog *self)
 }
 
 
+static gboolean
+_fr_file_selector_dialog_is_file_selected (FrFileSelectorDialog *self)
+{
+	if (self->selection_mode == FR_FILE_SELECTOR_MODE_FILES)
+		return _fr_file_selector_dialog_is_file_checked (self);
+	else
+		return self->current_folder != NULL;
+}
+
+
 static void
 _update_sensitivity (FrFileSelectorDialog *self)
 {
@@ -491,7 +496,6 @@ is_selected_cellrenderertoggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
 	GtkTreeIter           iter;
 	gboolean              is_selected;
 
-
 	list_store = GTK_LIST_STORE (GET_WIDGET ("files_liststore"));
 	tree_path = gtk_tree_path_new_from_string (path);
 	if (! gtk_tree_model_get_iter (GTK_TREE_MODEL (list_store), &iter, tree_path)) {
@@ -499,9 +503,9 @@ is_selected_cellrenderertoggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
 		return;
 	}
 
-        gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter,
-        		    FILE_LIST_COLUMN_IS_SELECTED, &is_selected,
-                            -1);
+	gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter,
+			    FILE_LIST_COLUMN_IS_SELECTED, &is_selected,
+			    -1);
 	gtk_list_store_set (list_store, &iter,
 			    FILE_LIST_COLUMN_IS_SELECTED, ! is_selected,
 			    -1);
@@ -512,6 +516,19 @@ is_selected_cellrenderertoggle_toggled_cb (GtkCellRendererToggle *cell_renderer,
 }
 
 
+static void
+files_treeview_selection_changed_cb (GtkTreeView *tree_view,
+				     gpointer     user_data)
+{
+	FrFileSelectorDialog *self = user_data;
+
+	if (self->selection_mode != FR_FILE_SELECTOR_MODE_FOLDER)
+		return;
+
+	_update_sensitivity (self);
+}
+
+
 static void
 files_treeview_row_activated_cb (GtkTreeView       *tree_view,
 				 GtkTreePath       *path,
@@ -528,66 +545,127 @@ files_treeview_row_activated_cb (GtkTreeView       *tree_view,
 	if (! gtk_tree_model_get_iter (tree_model, &iter, path))
 		return;
 
-        gtk_tree_model_get (tree_model, &iter,
-        		    FILE_LIST_COLUMN_FILE, &file,
-        		    FILE_LIST_COLUMN_IS_FOLDER, &is_folder,
-        		    -1);
-        if (is_folder)
-        	fr_file_selector_dialog_set_current_folder (self, file);
+	gtk_tree_model_get (tree_model, &iter,
+			    FILE_LIST_COLUMN_FILE, &file,
+			    FILE_LIST_COLUMN_IS_FOLDER, &is_folder,
+			    -1);
+	if (is_folder)
+		fr_file_selector_dialog_set_current_folder (self, file);
 
-        g_object_unref (file);
+	g_object_unref (file);
 }
 
 
 static void
-go_up_button_clicked_cb (GtkButton *button,
-			 gpointer   user_data)
+location_bar_changed_cb (FrLocationBar *location_bar,
+			 gpointer       user_data)
 {
 	FrFileSelectorDialog *self = user_data;
-	GFile                *parent;
-
-	if (self->current_folder == NULL)
-		return;
-
-	parent = g_file_get_parent (self->current_folder);
-	if (parent == NULL)
-		return;
-
-	fr_file_selector_dialog_set_current_folder (self, parent);
-
-	g_object_unref (parent);
+	fr_file_selector_dialog_set_current_folder (self, fr_location_bar_get_location (location_bar));
 }
 
 
 static void
-places_sidebar_open_location_cb (GtkPlacesSidebar  *sidebar,
-				 GFile             *location,
-				 GtkPlacesOpenFlags open_flags,
-				 gpointer           user_data)
+_set_current_folder (FrFileSelectorDialog *self,
+		     GFile                *folder,
+		     GList                *files);
+
+
+static void
+new_folder_dialog_response_cb (GtkDialog *dialog,
+			       int        response_id,
+			       gpointer   user_data)
 {
 	FrFileSelectorDialog *self = user_data;
 
+	if (response_id != GTK_RESPONSE_YES) {
+		gtk_window_destroy (GTK_WINDOW (dialog));
+		return;
+	}
+
+	char *filename = _gth_request_dialog_get_text (dialog);
+	if (filename == NULL)
+		return;
+
+	char *reason = NULL;
+	if (!_g_basename_is_valid (filename, NULL, &reason)) {
+		GtkWidget *dlg;
+
+		dlg = _gtk_error_dialog_new (GTK_WINDOW (dialog),
+					     GTK_DIALOG_DESTROY_WITH_PARENT,
+					     NULL,
+					     _("Could not create the folder"),
+					     "%s",
+					     reason);
+		_gtk_dialog_run (GTK_DIALOG (dlg));
+
+		g_free (reason);
+		g_free (filename);
+		return;
+	}
+
+	GFile  *new_folder = g_file_get_child_for_display_name (self->current_folder, filename, NULL);
+	GError *error = NULL;
+	if (!g_file_make_directory (new_folder, NULL, &error)) {
+		_gtk_error_dialog_run (GTK_WINDOW (dialog), _("Could not create the folder"), "%s", error->message);
+		g_error_free (error);
+	}
+	else {
+		gtk_window_destroy (GTK_WINDOW (dialog));
+
+		GList *selected_files = fr_file_selector_dialog_get_selected_files (self);
+		_set_current_folder (self, new_folder, selected_files);
+		_g_object_list_unref (selected_files);
+	}
+
+	g_object_unref (new_folder);
+	g_free (filename);
+}
+
+
+static void
+new_folder_button_clicked_cb (GtkButton *button,
+			      gpointer   user_data)
+{
+	FrFileSelectorDialog *self = user_data;
+	GtkWidget            *dialog;
+
+	dialog = _gtk_request_dialog_new (GTK_WINDOW (self),
+					  GTK_DIALOG_MODAL,
+					  C_("Window title", "New Folder"),
+					  _("_Name:"),
+					  "",
+					  1024,
+					  _GTK_LABEL_CANCEL,
+					  _GTK_LABEL_CREATE_ARCHIVE);
+	g_signal_connect (dialog,
+			  "response",
+			  G_CALLBACK (new_folder_dialog_response_cb),
+			  self);
+	gtk_window_present (GTK_WINDOW (dialog));
+}
+
+
+static void
+places_sidebar_open_cb (FrPlacesSidebar *sidebar,
+			GFile           *location,
+			gpointer         user_data)
+{
+	FrFileSelectorDialog *self = user_data;
 	fr_file_selector_dialog_set_current_folder (self, location);
 }
 
 
-static gboolean
-files_treeview_button_press_event_cb (GtkWidget      *widget,
-				      GdkEventButton *event,
-				      gpointer        user_data)
+static void
+files_treeview_button_pressed_cb (GtkGestureClick *gesture,
+				  gint             n_press,
+				  gdouble          x,
+				  gdouble          y,
+				  gpointer         user_data)
 {
 	FrFileSelectorDialog *self = user_data;
-
-	if (event->button == 3) {
-		int wx;
-		int wy;
-		gtk_tree_view_convert_bin_window_to_widget_coords (GTK_TREE_VIEW (widget), event->x, event->y, &wx, &wy);
-		_gtk_popover_popup_at_position (self->file_context_menu, wx, wy);
-
-		return TRUE;
-	}
-
-	return FALSE;
+	if (n_press == 1)
+		_gtk_popover_popup_at_position (self->file_context_menu, x, y);
 }
 
 
@@ -604,8 +682,8 @@ select_all_files (FrFileSelectorDialog *self,
 
 	do {
 		gtk_list_store_set (list_store, &iter,
-	        		    FILE_LIST_COLUMN_IS_SELECTED, value,
-	                            -1);
+				    FILE_LIST_COLUMN_IS_SELECTED, value,
+				    -1);
 	}
 	while (gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter));
 
@@ -624,23 +702,17 @@ select_all_activate_cb (GSimpleAction *action,
 
 static void
 unselect_all_activate_cb (GSimpleAction *action,
-				   GVariant *state,
-				    gpointer user_data)
+			  GVariant *state,
+			  gpointer user_data)
 {
 	select_all_files (FR_FILE_SELECTOR_DIALOG (user_data), FALSE);
 }
 
 
-static void
-_set_current_folder (FrFileSelectorDialog *self,
-		     GFile                *folder,
-		     GList                *files);
-
-
 static void
 show_hidden_files_toggled_cb (GSimpleAction *action,
-				       GVariant *state,
-				        gpointer user_data)
+			      GVariant *state,
+			      gpointer user_data)
 {
 	FrFileSelectorDialog *self = user_data;
 	GFile                *folder;
@@ -694,20 +766,48 @@ fr_file_selector_dialog_init (FrFileSelectorDialog *self)
 {
 	self->current_folder = NULL;
 	self->builder = gtk_builder_new_from_resource (FILE_ROLLER_RESOURCE_UI_PATH "file-selector.ui");
-	self->icon_cache = NULL;
 	self->settings = g_settings_new ("org.gnome.FileRoller.FileSelector");
 	self->show_hidden = g_settings_get_boolean (self->settings, PREF_FILE_SELECTOR_SHOW_HIDDEN);
 	self->action_map = g_simple_action_group_new ();
-	self->file_context_menu = GTK_POPOVER (gtk_popover_new_from_model (GET_WIDGET ("files_treeview"), G_MENU_MODEL (gtk_builder_get_object (self->builder, "file_list_context_menu_model"))));
+	self->file_context_menu = GTK_POPOVER (gtk_popover_menu_new_from_model (G_MENU_MODEL (gtk_builder_get_object (self->builder, "file_list_context_menu_model"))));
 
-	gtk_container_set_border_width (GTK_CONTAINER (self), 5);
-	gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), GET_WIDGET ("content"), TRUE, TRUE, 0);
+	gtk_popover_set_offset (GTK_POPOVER (self->file_context_menu), 0, 30);
+	gtk_box_prepend (GTK_BOX (GET_WIDGET ("file_list_container")), GTK_WIDGET (self->file_context_menu));
+
+	_gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (self))), GET_WIDGET ("content"), TRUE, TRUE);
 
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (GET_WIDGET ("files_liststore")), FILE_LIST_COLUMN_NAME, files_name_column_sort_func, self, NULL);
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (GET_WIDGET ("files_liststore")), FILE_LIST_COLUMN_SIZE, files_size_column_sort_func, self, NULL);
 	gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (GET_WIDGET ("files_liststore")), FILE_LIST_COLUMN_MODIFIED, files_modified_column_sort_func, self, NULL);
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (GET_WIDGET ("files_liststore")), FILE_LIST_COLUMN_NAME, GTK_SORT_ASCENDING);
 
+	GtkWidget *location_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (location_box)), "toolbar");
+	gtk_style_context_add_class (gtk_widget_get_style_context (GTK_WIDGET (location_box)), "locationbar");
+	_gtk_box_pack_start (GTK_BOX (GET_WIDGET ("content_box")), location_box, TRUE, FALSE);
+
+	self->location_bar = fr_location_bar_new ();
+	g_signal_connect (self->location_bar,
+			  "changed",
+			  G_CALLBACK (location_bar_changed_cb),
+			  self);
+	_gtk_box_pack_start (GTK_BOX (location_box), self->location_bar, TRUE, FALSE);
+
+	GtkWidget *new_folder_button = gtk_button_new_from_icon_name ("folder-new-symbolic");
+	gtk_widget_set_tooltip_text (new_folder_button, _("New Folder"));
+	g_signal_connect (new_folder_button,
+			  "clicked",
+			  G_CALLBACK (new_folder_button_clicked_cb),
+			  self);
+	_gtk_box_pack_end (GTK_BOX (location_box), new_folder_button, FALSE, FALSE);
+
+	self->places_sidebar = fr_places_sidebar_new ();
+	_gtk_box_pack_start (GTK_BOX (GET_WIDGET ("places_sidebar")), self->places_sidebar, TRUE, TRUE);
+	g_signal_connect (self->places_sidebar,
+			  "open",
+			  G_CALLBACK (places_sidebar_open_cb),
+			  self);
+
 	g_signal_connect (GTK_CELL_RENDERER_TOGGLE (GET_WIDGET ("is_selected_cellrenderertoggle")),
 			  "toggled",
 			  G_CALLBACK (is_selected_cellrenderertoggle_toggled_cb),
@@ -716,18 +816,18 @@ fr_file_selector_dialog_init (FrFileSelectorDialog *self)
 			  "row-activated",
 			  G_CALLBACK (files_treeview_row_activated_cb),
 			  self);
-	g_signal_connect (GTK_BUTTON (GET_WIDGET ("go_up_button")),
-			  "clicked",
-			  G_CALLBACK (go_up_button_clicked_cb),
+	g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW (GET_WIDGET ("files_treeview"))),
+			  "changed",
+			  G_CALLBACK (files_treeview_selection_changed_cb),
 			  self);
-	g_signal_connect (GTK_PLACES_SIDEBAR (GET_WIDGET ("places_sidebar")),
-			  "open-location",
-			  G_CALLBACK (places_sidebar_open_location_cb),
-			  self);
-	g_signal_connect (GTK_TREE_VIEW (GET_WIDGET ("files_treeview")),
-			  "button-press-event",
-			  G_CALLBACK (files_treeview_button_press_event_cb),
+
+	GtkGesture *gesture_click = gtk_gesture_click_new ();
+	gtk_gesture_single_set_button (GTK_GESTURE_SINGLE (gesture_click), GDK_BUTTON_SECONDARY);
+	g_signal_connect (gesture_click,
+			  "pressed",
+			  G_CALLBACK (files_treeview_button_pressed_cb),
 			  self);
+	gtk_widget_add_controller (GET_WIDGET ("files_treeview"), GTK_EVENT_CONTROLLER (gesture_click));
 
 	g_action_map_add_action_entries (G_ACTION_MAP (self->action_map),
 			dlg_entries, G_N_ELEMENTS (dlg_entries),
@@ -742,10 +842,12 @@ fr_file_selector_dialog_init (FrFileSelectorDialog *self)
 
 
 GtkWidget *
-fr_file_selector_dialog_new (const char *title,
-			     GtkWindow  *parent)
+fr_file_selector_dialog_new (FrFileSelectorMode  mode,
+			     const char         *title,
+			     GtkWindow          *parent)
 {
 	return (GtkWidget *) g_object_new (fr_file_selector_dialog_get_type (),
+					   "selection-mode", mode,
 					   "title", title,
 					   "transient-for", parent,
 					   "use-header-bar", _gtk_settings_get_dialogs_use_header (),
@@ -758,10 +860,10 @@ fr_file_selector_dialog_set_extra_widget (FrFileSelectorDialog *self,
 					  GtkWidget            *extra_widget)
 {
 	if (self->extra_widget != NULL)
-		gtk_container_remove (GTK_CONTAINER (GET_WIDGET ("extra_widget_container")), self->extra_widget);
+		gtk_box_remove (GTK_BOX (GET_WIDGET ("extra_widget_container")), self->extra_widget);
 	self->extra_widget = extra_widget;
 	if (self->extra_widget != NULL)
-		gtk_container_add (GTK_CONTAINER (GET_WIDGET ("extra_widget_container")), self->extra_widget);
+		gtk_box_append (GTK_BOX (GET_WIDGET ("extra_widget_container")), self->extra_widget);
 }
 
 
@@ -825,7 +927,7 @@ folder_mount_enclosing_volume_ready_cb (GObject      *source_object,
 
 static void
 get_folder_content_done_cb (GError   *error,
-		            gpointer  user_data)
+			    gpointer  user_data)
 {
 	LoadData             *load_data = user_data;
 	FrFileSelectorDialog *self = load_data->dialog;
@@ -879,7 +981,7 @@ get_folder_content_done_cb (GError   *error,
 	gtk_list_store_clear (list_store);
 	for (scan = load_data->files; scan; scan = scan->next) {
 		FileInfo  *file_info = scan->data;
-		GdkPixbuf *icon_pixbuf;
+		GIcon     *icon;
 		char      *size;
 		GTimeVal   timeval;
 		GDateTime *datetime;
@@ -892,7 +994,7 @@ get_folder_content_done_cb (GError   *error,
 
 		gtk_list_store_append (list_store, &iter);
 
-		icon_pixbuf = gth_icon_cache_get_pixbuf (self->icon_cache, g_file_info_get_icon (file_info->info));
+		icon = g_file_info_get_icon (file_info->info);
 		size = g_format_size (g_file_info_get_size (file_info->info));
 		g_file_info_get_modification_time (file_info->info, &timeval);
 		datetime = g_date_time_new_from_timeval_local (&timeval);
@@ -901,7 +1003,7 @@ get_folder_content_done_cb (GError   *error,
 		is_folder = (g_file_info_get_file_type (file_info->info) == G_FILE_TYPE_DIRECTORY);
 
 		gtk_list_store_set (list_store, &iter,
-				    FILE_LIST_COLUMN_ICON, icon_pixbuf,
+				    FILE_LIST_COLUMN_ICON, icon,
 				    FILE_LIST_COLUMN_NAME, g_file_info_get_display_name (file_info->info),
 				    FILE_LIST_COLUMN_SIZE, (is_folder ? "" : size),
 				    FILE_LIST_COLUMN_MODIFIED, modified,
@@ -917,7 +1019,6 @@ get_folder_content_done_cb (GError   *error,
 		g_free (modified);
 		g_date_time_unref (datetime);
 		g_free (size);
-		_g_object_unref (icon_pixbuf);
 	}
 
 	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (GET_WIDGET ("files_liststore")), sort_column_id, sort_order);
@@ -941,6 +1042,10 @@ get_folder_content_for_each_child_cb (GFile     *file,
 	LoadData *load_data = user_data;
 	FileInfo *file_info;
 
+	if (load_data->dialog->selection_mode == FR_FILE_SELECTOR_MODE_FOLDER)
+		if (g_file_info_get_file_type (info) != G_FILE_TYPE_DIRECTORY)
+			return;
+
 	file_info = file_info_new (file, info);
 	load_data->files = g_list_prepend (load_data->files, file_info);
 }
@@ -952,19 +1057,20 @@ _get_folder_list (LoadData *load_data)
 	g_directory_foreach_child (load_data->folder,
 				   FALSE,
 				   TRUE,
-			           (G_FILE_ATTRIBUTE_STANDARD_TYPE ","
-			            G_FILE_ATTRIBUTE_STANDARD_NAME ","
-			            G_FILE_ATTRIBUTE_STANDARD_SIZE ","
-			            G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME ","
-			            G_FILE_ATTRIBUTE_STANDARD_ICON ","
-			            G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN ","
-			            G_FILE_ATTRIBUTE_TIME_MODIFIED ","
-			            G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC),
-			            load_data->cancellable,
-			           NULL,
-			           get_folder_content_for_each_child_cb,
-			           get_folder_content_done_cb,
-			           load_data);
+				   (G_FILE_ATTRIBUTE_STANDARD_TYPE ","
+				    G_FILE_ATTRIBUTE_STANDARD_NAME ","
+				    G_FILE_ATTRIBUTE_STANDARD_SIZE ","
+				    G_FILE_ATTRIBUTE_STANDARD_DISPLAY_NAME ","
+				    G_FILE_ATTRIBUTE_STANDARD_ICON ","
+				    G_FILE_ATTRIBUTE_STANDARD_SYMBOLIC_ICON ","
+				    G_FILE_ATTRIBUTE_STANDARD_IS_HIDDEN ","
+				    G_FILE_ATTRIBUTE_TIME_MODIFIED ","
+				    G_FILE_ATTRIBUTE_TIME_MODIFIED_USEC),
+				   load_data->cancellable,
+				   NULL,
+				   get_folder_content_for_each_child_cb,
+				   get_folder_content_done_cb,
+				   load_data);
 }
 
 
@@ -990,7 +1096,6 @@ fr_file_selector_dialog_set_current_folder (FrFileSelectorDialog *self,
 					    GFile                *folder)
 {
 	g_return_if_fail (folder != NULL);
-
 	_set_current_folder (self, folder, NULL);
 }
 
@@ -1034,15 +1139,15 @@ fr_file_selector_dialog_get_selected_files (FrFileSelectorDialog *self)
 		GFile    *file;
 		gboolean  is_selected;
 
-	        gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter,
-	        		    FILE_LIST_COLUMN_FILE, &file,
-	        		    FILE_LIST_COLUMN_IS_SELECTED, &is_selected,
-	                            -1);
+		gtk_tree_model_get (GTK_TREE_MODEL (list_store), &iter,
+				    FILE_LIST_COLUMN_FILE, &file,
+				    FILE_LIST_COLUMN_IS_SELECTED, &is_selected,
+				    -1);
 
-	        if (is_selected)
-	        	list = g_list_prepend (list, g_object_ref (file));
+		if (is_selected)
+			list = g_list_prepend (list, g_object_ref (file));
 
-	        g_object_unref (file);
+		g_object_unref (file);
 	}
 	while (gtk_tree_model_iter_next (GTK_TREE_MODEL (list_store), &iter));
 
