@@ -22,7 +22,7 @@
 #include <config.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
-#include "file-data.h"
+#include "fr-file-data.h"
 #include "file-utils.h"
 #include "glib-utils.h"
 #if ENABLE_LIBARCHIVE
@@ -86,6 +86,8 @@ FrMimeTypeDescription mime_type_desc[] = {
 	{ "application/x-deb",                     ".deb",      0 },
 	{ "application/x-debian-package",          ".deb",      0 },
 	{ "application/vnd.debian.binary-package", ".deb",      0 },
+	{ "application/x-apple-diskimage",         ".dmg",      0 },
+	{ "application/vnd.rar",                   ".rar",      0 },
 	{ "application/vnd.snap",                  ".snap",     0 },
 	{ "application/vnd.squashfs",              ".sqsh",     0 },
 	{ "application/x-ear",                     ".ear",      0 },
@@ -140,6 +142,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".cpio", "application/x-cpio" },
 	{ ".crx", "application/x-chrome-extension" },
 	{ ".deb", "application/x-deb" },
+	{ ".dmg", "application/x-apple-diskimage" },
 	{ ".ear", "application/x-ear" },
 	{ ".epub", "application/epub+zip" },
 	{ ".exe", "application/x-ms-dos-executable" },
@@ -153,7 +156,7 @@ FrExtensionType file_ext_type[] = {
 	{ ".lz4", "application/x-lz4" },
 	{ ".lzma", "application/x-lzma" },
 	{ ".lzo", "application/x-lzop" },
-	{ ".rar", "application/x-rar" },
+	{ ".rar", "application/vnd.rar" },
 	{ ".rpm", "application/x-rpm" },
 	{ ".rz", "application/x-rzip" },
 	{ ".sit", "application/x-stuffit" },
@@ -202,36 +205,10 @@ GList        *CommandList;
 gint          ForceDirectoryCreation;
 GHashTable   *ProgramsCache;
 GPtrArray    *Registered_Archives;
-int           single_file_save_type[64];
-int           save_type[64];
-int           open_type[64];
-int           create_type[64];
-
-
-static void
-migrate_options_directory (void)
-{
-	char *old_directory_path;
-	GFile *old_directory;
-	GFile *new_directory;
-
-	old_directory_path = get_home_relative_path (".gnome2/file-roller/options");
-	old_directory = g_file_new_for_path (old_directory_path);
-	new_directory = _g_file_new_user_config_subdir (ADD_FOLDER_OPTIONS_DIR, FALSE);
-	if (g_file_query_exists (old_directory, NULL) && ! g_file_query_exists (new_directory, NULL)) {
-		GFile *parent;
-
-		parent = g_file_get_parent (new_directory);
-		if (_g_file_make_directory_tree (parent, 0700, NULL))
-			g_file_move (old_directory, new_directory, 0, NULL, NULL, NULL, NULL);
-
-		g_object_unref (parent);
-	}
-
-	g_object_unref (new_directory);
-	g_object_unref (old_directory);
-	g_free (old_directory_path);
-}
+int           single_file_save_type[G_N_ELEMENTS (mime_type_desc)];
+int           save_type[G_N_ELEMENTS (mime_type_desc)];
+int           open_type[G_N_ELEMENTS (mime_type_desc)];
+int           create_type[G_N_ELEMENTS (mime_type_desc)];
 
 
 /* -- FrRegisteredArchive -- */
@@ -243,17 +220,16 @@ fr_registered_archive_new (GType command_type)
 	FrRegisteredArchive  *reg_com;
 	FrArchive            *archive;
 	const char          **mime_types;
-	int                   i;
 
 	reg_com = g_new0 (FrRegisteredArchive, 1);
 	reg_com->ref = 1;
 	reg_com->type = command_type;
-	reg_com->caps = g_ptr_array_new ();
-	reg_com->packages = g_ptr_array_new ();
+	reg_com->caps = g_ptr_array_new_with_free_func (g_free);
+	reg_com->packages = g_ptr_array_new_with_free_func (g_free);
 
 	archive = (FrArchive*) g_object_new (reg_com->type, NULL);
 	mime_types = fr_archive_get_supported_types (archive);
-	for (i = 0; mime_types[i] != NULL; i++) {
+	for (size_t i = 0; mime_types[i] != NULL; i++) {
 		const char         *mime_type;
 		FrMimeTypeCap      *cap;
 		FrMimeTypePackages *packages;
@@ -291,7 +267,6 @@ fr_registered_archive_unref (FrRegisteredArchive *reg_com)
 	if (--(reg_com->ref) != 0)
 		return;
 
-	g_ptr_array_foreach (reg_com->caps, (GFunc) g_free, NULL);
 	g_ptr_array_free (reg_com->caps, TRUE);
 	g_free (reg_com);
 }
@@ -301,9 +276,7 @@ static FrArchiveCaps
 fr_registered_archive_get_capabilities (FrRegisteredArchive *reg_com,
 				        const char          *mime_type)
 {
-	int i;
-
-	for (i = 0; i < reg_com->caps->len; i++) {
+	for (guint i = 0; i < reg_com->caps->len; i++) {
 		FrMimeTypeCap *cap;
 
 		cap = g_ptr_array_index (reg_com->caps, i);
@@ -319,12 +292,10 @@ static FrArchiveCaps
 fr_registered_archive_get_potential_capabilities (FrRegisteredArchive *reg_com,
 						  const char          *mime_type)
 {
-	int i;
-
 	if (mime_type == NULL)
 		return FR_ARCHIVE_CAN_DO_NOTHING;
 
-	for (i = 0; i < reg_com->caps->len; i++) {
+	for (guint i = 0; i < reg_com->caps->len; i++) {
 		FrMimeTypeCap *cap;
 
 		cap = g_ptr_array_index (reg_com->caps, i);
@@ -348,9 +319,7 @@ register_archive (GType command_type)
 G_GNUC_UNUSED static gboolean
 unregister_archive (GType command_type)
 {
-	int i;
-
-	for (i = 0; i < Registered_Archives->len; i++) {
+	for (guint i = 0; i < Registered_Archives->len; i++) {
 		FrRegisteredArchive *archive;
 
 		archive = g_ptr_array_index (Registered_Archives, i);
@@ -404,15 +373,13 @@ register_archives (void)
 
 
 GType
-get_archive_type_from_mime_type (const char    *mime_type,
+fr_get_archive_type_from_mime_type (const char    *mime_type,
 				 FrArchiveCaps  requested_capabilities)
 {
-	int i;
-
 	if (mime_type == NULL)
 		return 0;
 
-	for (i = 0; i < Registered_Archives->len; i++) {
+	for (guint i = 0; i < Registered_Archives->len; i++) {
 		FrRegisteredArchive *command;
 		FrArchiveCaps        capabilities;
 
@@ -429,12 +396,10 @@ get_archive_type_from_mime_type (const char    *mime_type,
 
 
 GType
-get_preferred_archive_for_mime_type (const char    *mime_type,
+fr_get_preferred_archive_for_mime_type (const char    *mime_type,
 				     FrArchiveCaps  requested_capabilities)
 {
-	int i;
-
-	for (i = 0; i < Registered_Archives->len; i++) {
+	for (guint i = 0; i < Registered_Archives->len; i++) {
 		FrRegisteredArchive *archive;
 		FrArchiveCaps        capabilities;
 
@@ -451,20 +416,17 @@ get_preferred_archive_for_mime_type (const char    *mime_type,
 
 
 void
-update_registered_archives_capabilities (void)
+fr_update_registered_archives_capabilities (void)
 {
-	int i;
-
 	g_hash_table_remove_all (ProgramsCache);
 
-	for (i = 0; i < Registered_Archives->len; i++) {
+	for (guint i = 0; i < Registered_Archives->len; i++) {
 		FrRegisteredArchive *reg_com;
 		FrArchive           *archive;
-		int                  j;
 
 		reg_com = g_ptr_array_index (Registered_Archives, i);
 		archive = g_object_new (reg_com->type, NULL);
-		for (j = 0; j < reg_com->caps->len; j++) {
+		for (guint j = 0; j < reg_com->caps->len; j++) {
 			FrMimeTypeCap *cap = g_ptr_array_index (reg_com->caps, j);
 
 			cap->current_capabilities = fr_archive_get_capabilities (archive, cap->mime_type, TRUE);
@@ -514,7 +476,7 @@ _g_mime_type_get_from_filename (GFile *file)
 
 
 const char *
-get_archive_filename_extension (const char *filename)
+fr_get_archive_filename_extension (const char *filename)
 {
 	const char *ext;
 	int         i;
@@ -538,7 +500,7 @@ get_archive_filename_extension (const char *filename)
 
 
 int
-get_mime_type_index (const char *mime_type)
+fr_get_mime_type_index (const char *mime_type)
 {
 	int i;
 
@@ -589,7 +551,7 @@ sort_mime_types (int *a,
 
 
 void
-sort_mime_types_by_extension (int *a)
+fr_sort_mime_types_by_extension (int *a)
 {
 	sort_mime_types (a, cmp_mime_type_by_extension);
 }
@@ -599,19 +561,17 @@ static void
 compute_supported_archive_types (void)
 {
 	int sf_i = 0, s_i = 0, o_i = 0, c_i = 0;
-	int i;
 
-	for (i = 0; i < Registered_Archives->len; i++) {
+	for (guint i = 0; i < Registered_Archives->len; i++) {
 		FrRegisteredArchive *reg_com;
-		int                  j;
 
 		reg_com = g_ptr_array_index (Registered_Archives, i);
-		for (j = 0; j < reg_com->caps->len; j++) {
+		for (guint j = 0; j < reg_com->caps->len; j++) {
 			FrMimeTypeCap *cap;
 			int            idx;
 
 			cap = g_ptr_array_index (reg_com->caps, j);
-			idx = get_mime_type_index (cap->mime_type);
+			idx = fr_get_mime_type_index (cap->mime_type);
 			if (idx < 0) {
 				g_warning ("mime type not recognized: %s", cap->mime_type);
 				continue;
@@ -641,28 +601,19 @@ static gboolean initialized = FALSE;
 
 
 void
-initialize_data (void)
+fr_initialize_data (void)
 {
 	if (initialized)
 		return;
 	initialized = TRUE;
-
-	ProgramsCache = g_hash_table_new_full (g_str_hash,
-					       g_str_equal,
-					       g_free,
-					       NULL);
-
-	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
-					   PRIVDATADIR G_DIR_SEPARATOR_S "icons");
-
-	migrate_options_directory ();
+	ProgramsCache = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
 	register_archives ();
 	compute_supported_archive_types ();
 }
 
 
 static void
-command_done (CommandData *cdata)
+command_done (FrCommandData *cdata)
 {
 	if (cdata == NULL)
 		return;
@@ -681,13 +632,13 @@ command_done (CommandData *cdata)
 
 
 void
-release_data (void)
+fr_release_data (void)
 {
 	if (! initialized)
 		return;
 
 	while (CommandList != NULL) {
-		CommandData *cdata = CommandList->data;
+		FrCommandData *cdata = CommandList->data;
 		command_done (cdata);
 	}
 }
