@@ -28,25 +28,17 @@
 #include "fr-error.h"
 #include "typedefs.h"
 
-#define FR_TYPE_PROCESS            (fr_process_get_type ())
-#define FR_PROCESS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FR_TYPE_PROCESS, FrProcess))
-#define FR_PROCESS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), FR_TYPE_PROCESS, FrProcessClass))
-#define FR_IS_PROCESS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), FR_TYPE_PROCESS))
-#define FR_IS_PROCESS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), FR_TYPE_PROCESS))
-#define FR_PROCESS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), FR_TYPE_PROCESS, FrProcessClass))
+#define FR_TYPE_PROCESS (fr_process_get_type ())
+G_DECLARE_FINAL_TYPE (FrProcess, fr_process, FR, PROCESS, GObject)
 
-typedef struct _FrProcess        FrProcess;
-typedef struct _FrProcessClass   FrProcessClass;
-typedef struct _FrProcessPrivate FrProcessPrivate;
-
-typedef void     (*ProcFunc)     (gpointer data);
-typedef gboolean (*ContinueFunc) (FrError **error, gpointer data);
-typedef void     (*LineFunc)     (char *line, gpointer data);
+typedef void     (*FrProcFunc)     (gpointer data);
+typedef gboolean (*FrContinueFunc) (FrError **error, gpointer data);
+typedef void     (*FrLineFunc)     (char *line, gpointer data);
 
 typedef struct {
 	GIOChannel *source;
 	GList      *raw;
-	LineFunc    line_func;
+	FrLineFunc    line_func;
 	gpointer    line_data;
 	GIOStatus   status;
 	GError     *error;
@@ -57,20 +49,10 @@ struct _FrProcess {
 
 	FrChannelData     out;
 	FrChannelData     err;
-	gboolean          restart;       /* whether to restart the process
-			  		  * after an error. */
-	FrProcessPrivate *priv;
+	/* whether to restart the process after an error. */
+	gboolean          restart;
 };
 
-struct _FrProcessClass {
-	GObjectClass __parent_class;
-
-	/* -- Signals -- */
-
-	void (* sticky_only) (FrProcess *fr_proc);
-};
-
-GType       fr_process_get_type             (void);
 FrProcess * fr_process_new                  (void);
 void        fr_process_clear                (FrProcess            *fr_proc);
 void        fr_process_begin_command        (FrProcess            *fr_proc,
@@ -93,13 +75,13 @@ void        fr_process_set_arg_at           (FrProcess            *fr_proc,
 					     int                   n_arg,
 					     const char           *arg);
 void        fr_process_set_begin_func       (FrProcess            *fr_proc,
-					     ProcFunc              func,
+					     FrProcFunc              func,
 					     gpointer              func_data);
 void        fr_process_set_end_func         (FrProcess            *fr_proc,
-					     ProcFunc              func,
+					     FrProcFunc              func,
 					     gpointer              func_data);
 void        fr_process_set_continue_func    (FrProcess            *fr_proc,
-					     ContinueFunc          func,
+					     FrContinueFunc          func,
 					     gpointer              func_data);
 void        fr_process_end_command          (FrProcess            *fr_proc);
 void        fr_process_set_working_dir      (FrProcess            *fr_proc,
@@ -113,10 +95,10 @@ void        fr_process_set_ignore_error     (FrProcess            *fr_proc,
 void        fr_process_use_standard_locale  (FrProcess            *fr_proc,
 					     gboolean              use_stand_locale);
 void        fr_process_set_out_line_func    (FrProcess            *fr_proc,
-					     LineFunc              func,
+					     FrLineFunc              func,
 					     gpointer              func_data);
 void        fr_process_set_err_line_func    (FrProcess            *fr_proc,
-					     LineFunc              func,
+					     FrLineFunc              func,
 					     gpointer              func_data);
 void        fr_process_execute              (FrProcess            *process,
 					     GCancellable         *cancellable,
