@@ -37,10 +37,12 @@ DEF_ACTION_CALLBACK (fr_window_activate_edit_cut)
 DEF_ACTION_CALLBACK (fr_window_activate_edit_password)
 DEF_ACTION_CALLBACK (fr_window_activate_edit_paste)
 DEF_ACTION_CALLBACK (fr_window_activate_extract_files)
+DEF_ACTION_CALLBACK (fr_window_activate_extract_all_by_default)
 DEF_ACTION_CALLBACK (fr_window_activate_find)
 DEF_ACTION_CALLBACK (fr_window_activate_go_back)
 DEF_ACTION_CALLBACK (fr_window_activate_go_forward)
 DEF_ACTION_CALLBACK (fr_window_activate_go_home)
+DEF_ACTION_CALLBACK (fr_window_activate_go_up_one_level)
 DEF_ACTION_CALLBACK (fr_window_activate_navigate_to)
 DEF_ACTION_CALLBACK (fr_window_activate_new)
 DEF_ACTION_CALLBACK (fr_window_activate_open)
@@ -62,5 +64,6 @@ DEF_ACTION_CALLBACK (fr_window_activate_test_archive)
 DEF_ACTION_CALLBACK (fr_window_activate_view_properties)
 DEF_ACTION_CALLBACK (fr_window_activate_view_selection)
 DEF_ACTION_CALLBACK (fr_window_activate_view_sidebar)
+DEF_ACTION_CALLBACK (fr_window_activate_focus_location)
 
 #endif /* FR_WINDOW_ACTION_CALLBACKS_H */
