@@ -76,10 +76,18 @@ _g_object_list_ref (GList *list)
 void
 _g_object_list_unref (GList *list)
 {
-	g_list_foreach (list, (GFunc) g_object_unref, NULL);
-	g_list_free (list);
+	g_list_free_full (list, (GDestroyNotify) g_object_unref);
 }
 
+
+void
+_g_object_unref_on_weak_notify (gpointer  data,
+				GObject  *where_the_object_was)
+{
+	g_object_unref (data);
+}
+
+
 /* enum */
 
 
@@ -203,7 +211,7 @@ count_chars_to_escape (const char *str,
 }
 
 
-char *
+static char *
 _g_str_escape_full (const char *str,
 		    const char *meta_chars,
 		    const char  prefix,
@@ -462,8 +470,7 @@ _g_string_list_free (GList *path_list)
 {
 	if (path_list == NULL)
 		return;
-	g_list_foreach (path_list, (GFunc) g_free, NULL);
-	g_list_free (path_list);
+	g_list_free_full (path_list, g_free);
 }
 
 
@@ -480,74 +487,6 @@ _g_string_list_dup (GList *path_list)
 }
 
 
-/* GPtrArray */
-
-
-GPtrArray *
-_g_ptr_array_copy (GPtrArray *array)
-{
-	GPtrArray *new_array;
-
-	if (array == NULL)
-		return NULL;
-
-	new_array = g_ptr_array_sized_new (array->len);
-	memcpy (new_array->pdata, array->pdata, array->len * sizeof (gpointer));
-	new_array->len = array->len;
-
-	return new_array;
-}
-
-
-void
-_g_ptr_array_free_full (GPtrArray *array,
-                        GFunc      free_func,
-                        gpointer   user_data)
-{
-	g_ptr_array_foreach (array, free_func, user_data);
-	g_ptr_array_free (array, TRUE);
-}
-
-
-void
-_g_ptr_array_reverse (GPtrArray *array)
-{
-	int      i, j;
-	gpointer tmp;
-
-	for (i = 0; i < array->len / 2; i++) {
-		j = array->len - i - 1;
-		tmp = g_ptr_array_index (array, i);
-		g_ptr_array_index (array, i) = g_ptr_array_index (array, j);
-		g_ptr_array_index (array, j) = tmp;
-	}
-}
-
-
-int
-_g_ptr_array_binary_search (GPtrArray    *array,
-			   gpointer      value,
-			   GCompareFunc  func)
-{
-	int l, r, p, cmp = -1;
-
-	l = 0;
-	r = array->len;
-	while (l < r) {
-		p = l + ((r - l) / 2);
-		cmp = func(value, &g_ptr_array_index (array, p));
-		if (cmp == 0)
-			return p;
-		else if (cmp < 0)
-			r = p;
-		else
-			l = p + 1;
-	}
-
-	return -1;
-}
-
-
 /* GRegex */
 
 
@@ -769,30 +708,6 @@ _g_regexp_split_from_patterns (const char         *pattern_string,
 }
 
 
-/* time */
-
-
-char *
-_g_time_to_string (time_t time)
-{
-	struct tm *tm;
-	char       s_time[256];
-	char      *locale_format = NULL;
-	char      *time_utf8;
-
-	tm = localtime (&time);
-	/* This is the time format used in the "Date Modified" column and
-	 * in the Properties dialog.  See the man page of strftime for an
-	 * explanation of the values. */
-	locale_format = g_locale_from_utf8 (_("%d %B %Y, %H:%M"), -1, NULL, NULL, NULL);
-	strftime (s_time, sizeof (s_time) - 1, locale_format, tm);
-	g_free (locale_format);
-	time_utf8 = g_locale_to_utf8 (s_time, -1, NULL, NULL, NULL);
-
-	return time_utf8;
-}
-
-
 /* uri/path/filename */
 
 
@@ -1042,7 +957,7 @@ _g_path_get_relative_basename (const char *path,
 			       const char *base_dir,
 			       gboolean    junk_paths)
 {
-	int         base_dir_len;
+	size_t      base_dir_len;
 	const char *base_path;
 
 	if (junk_paths)
@@ -1153,7 +1068,7 @@ gboolean
 _g_filename_has_extension (const char *filename,
 		   const char *ext)
 {
-	int filename_l, ext_l;
+	size_t filename_l, ext_l;
 
 	filename_l = strlen (filename);
 	ext_l = strlen (ext);
@@ -1220,7 +1135,7 @@ _g_mime_type_get_from_content (char  *buffer,
 		{ 0,  2, "\037\213",                             "application/x-gzip"          },
 		{ 0,  4, "LZIP",                                 "application/x-lzip"          },
 		{ 0,  9, "\x89\x4c\x5a\x4f\x00\x0d\x0a\x1a\x0a", "application/x-lzop",         },
-		{ 0,  4, "Rar!",                                 "application/x-rar"           },
+		{ 0,  4, "Rar!",                                 "application/vnd.rar"         },
 		{ 0,  4, "RZIP",                                 "application/x-rzip"          },
 		{ 0,  6, "\3757zXZ\000",                         "application/x-xz"            },
 		{ 20, 4, "\xdc\xa7\xc4\xfd",                     "application/x-zoo",          },
@@ -1230,9 +1145,7 @@ _g_mime_type_get_from_content (char  *buffer,
 		{ 0,  4, "\x28\xB5\x2F\xFD",                     "application/zstd"            },
 	};
 
-	int  i;
-
-	for (i = 0; i < G_N_ELEMENTS (magic_ids); i++) {
+	for (size_t i = 0; i < G_N_ELEMENTS (magic_ids); i++) {
 		const struct magic * const magic = &magic_ids[i];
 
 		if ((magic->off + magic->len) > buffer_size)
@@ -1245,6 +1158,42 @@ _g_mime_type_get_from_content (char  *buffer,
 }
 
 
+#define BAD_CHARS "/\\*"
+
+
+gboolean
+_g_basename_is_valid (const char          *new_name,
+		      const char          *old_name,
+		      char               **reason)
+{
+	char     *utf8_new_name;
+	gboolean  retval = TRUE;
+
+	new_name = _g_str_eat_spaces (new_name);
+	utf8_new_name = g_filename_display_name (new_name);
+
+	if (*new_name == '\0') {
+		/* Translators: the name references to a filename.  This message can appear when renaming a file. */
+		*reason = g_strdup (_("New name is void, please type a name."));
+		retval = FALSE;
+	}
+	else if ((old_name != NULL) && (strcmp (new_name, old_name) == 0)) {
+		/* Translators: the name references to a filename.  This message can appear when renaming a file. */
+		*reason = g_strdup (_("New name is the same as old one, please type other name."));
+		retval = FALSE;
+	}
+	else if (_g_strchrs (new_name, BAD_CHARS)) {
+		/* Translators: the %s references to a filename.  This message can appear when renaming a file. */
+		*reason = g_strdup_printf (_("Name “%s” is not valid because it contains at least one of the following characters: %s, please type other name."), utf8_new_name, BAD_CHARS);
+		retval = FALSE;
+	}
+
+	g_free (utf8_new_name);
+
+	return retval;
+}
+
+
 /* GFile */
 
 
@@ -1476,7 +1425,7 @@ int
 _g_line_get_index_from_pattern (const char *line,
 				const char *pattern)
 {
-	int         line_l, pattern_l;
+	size_t      line_l, pattern_l;
 	const char *l;
 
 	line_l = strlen (line);
